@@ -7,11 +7,12 @@ from typing import (
     Dict, 
     List, 
     Optional, 
-    AsyncGenerator
+    AsyncGenerator,
+    Union
 )
 from sqlalchemy.ext.asyncio import AsyncSession
 from sqlalchemy import select, and_, or_
-from sqlalchemy.orm import DeclarativeBase, joinedload, selectinload, noload
+from sqlalchemy.orm import DeclarativeBase, joinedload, selectinload, contains_eager
 from sqlalchemy.exc import SQLAlchemyError
 from datetime import datetime
 from contextlib import asynccontextmanager
@@ -151,21 +152,36 @@ def process_response(
     if not entity:
         return None
 
+    print(f"\n[DEBUG] Processing entity: {entity.__class__.__name__}")
+    print(f"[DEBUG] Entity dict: {entity.__dict__}")
+
     # 모든 필드 처리
     result = process_columns(entity)
+    print(f"[DEBUG] After process_columns: {result}")
     
     # Relationship 처리 (이미 로드된 관계만 처리)
     for relationship in entity.__mapper__.relationships:
+        print(f"\n[DEBUG] Processing relationship: {relationship.key}")
         if not relationship.key in entity.__dict__:
+            print(f"[DEBUG] Relationship {relationship.key} not in entity.__dict__")
             continue
             
         try:
             value = getattr(entity, relationship.key)
+            print(f"[DEBUG] Relationship value: {value}")
+            
             # response_model이 있는 경우 해당 필드의 annotation type을 가져옴
             nested_response_model = None
             if response_model and relationship.key in response_model.model_fields:
                 field_info = response_model.model_fields[relationship.key]
                 nested_response_model = field_info.annotation
+                print(f"[DEBUG] Found nested response model for {relationship.key}: {nested_response_model}")
+                
+                # Optional[ProjectResponse] 같은 경우 실제 모델 추출
+                if hasattr(nested_response_model, '__origin__') and nested_response_model.__origin__ is Union:
+                    print(f"[DEBUG] Extracting actual model from Union type: {nested_response_model.__args__}")
+                    nested_response_model = next((t for t in nested_response_model.__args__ if hasattr(t, 'model_fields')), None)
+                    print(f"[DEBUG] Extracted model: {nested_response_model}")
             
             if value is not None:
                 if isinstance(value, list):
@@ -174,23 +190,39 @@ def process_response(
                         for item in value
                     ]
                 else:
+                    print(f"[DEBUG] Processing single value with model: {nested_response_model}")
                     result[relationship.key] = process_response(value, nested_response_model)
+                print(f"[DEBUG] After processing relationship {relationship.key}: {result[relationship.key]}")
             else:
                 result[relationship.key] = None
-        except Exception:
+        except Exception as e:
+            print(f"[DEBUG] Error processing relationship {relationship.key}: {str(e)}")
+            import traceback
+            print(f"[DEBUG] Full traceback: {traceback.format_exc()}")
             result[relationship.key] = None
 
+    print(f"\n[DEBUG] Before response model processing: {result}")
     # response_model이 있는 경우 필터링
     if response_model:
+        print(f"[DEBUG] Response model fields: {response_model.model_fields}")
         # 현재 키 목록을 저장
         current_keys = list(result.keys())
         # response_model에 없는 키 제거
         for key in current_keys:
             if key not in response_model.model_fields:
+                print(f"[DEBUG] Removing key not in response model: {key}")
                 result.pop(key)
         # 모델 검증 및 업데이트
-        result.update(response_model(**result).model_dump())
+        try:
+            validated_result = response_model(**result).model_dump()
+            print(f"[DEBUG] After validation: {validated_result}")
+            result.update(validated_result)
+        except Exception as e:
+            print(f"[DEBUG] Error during validation: {str(e)}")
+            import traceback
+            print(f"[DEBUG] Full validation traceback: {traceback.format_exc()}")
             
+    print(f"[DEBUG] Final result: {result}")
     return result
 
 ##################
@@ -448,16 +480,17 @@ async def list_entities(
         List[Dict[str, Any]]: 쿼리 결과 리스트.
     """
     try:
-        # 메인 모델과 조인된 모델의 모든 컬럼을 명시적으로 선택
+        query = select(model)
+
+        # 명시적 조인 적용
         if explicit_joins:
-            query = select(model, *explicit_joins)
             for join_target in explicit_joins:
                 query = query.outerjoin(join_target)
-        else:
-            query = select(model)
 
-        # 불필요한 lazy loading 방지를 위해 noload 옵션 추가
-        query = query.options(noload('*'))
+        # 조인 로딩 적용
+        if loading_joins:
+            for join_option in loading_joins:
+                query = query.options(join_option)
 
         # 필터 조건 적용
         if filters:
@@ -484,7 +517,6 @@ async def list_entities(
         query = query.limit(limit).offset(skip)
 
         result = await session.execute(query)
-        
         return result.unique().scalars().all()
     except SQLAlchemyError as e:
         raise CustomException(
@@ -502,15 +534,14 @@ async def get_entity(
     loading_joins: Optional[List[Any]] = None
 ) -> ModelType:
     try:
-        # project 정보도 함께 select
-        query = select(model, *[join_target for join_target in (explicit_joins or [])])
+        query = select(model)
 
         # 명시적 조인 적용
         if explicit_joins:
             for join_target in explicit_joins:
-                query = query.outerjoin(join_target)  # LEFT OUTER JOIN 적용
+                query = query.outerjoin(join_target)
 
-        # 조인 로딩 적용 (제거 가능)
+        # 조인 로딩 적용
         if loading_joins:
             for join_option in loading_joins:
                 query = query.options(join_option)
